@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.27
+0.28
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 L<Mojo::IRC> is a non-blocking IRC client using L<Mojo::IOLoop> from the
 wonderful L<Mojolicious> framework.
 
-If features IPv6 and TLS, with additional optional modules:
+It features IPv6 and TLS, with additional optional modules:
 L<IO::Socket::IP> and L<IO::Socket::SSL>.
 
 By default this module will only emit standard IRC events, but by
@@ -55,7 +55,7 @@ Example:
 It will also set up some default events: L</ctcp_ping>, L</ctcp_time>,
 and L</ctcp_version>.
 
-This class inherit from L<Mojo::EventEmitter>.
+This class inherits from L<Mojo::EventEmitter>.
 
 =head1 TESTING
 
@@ -69,7 +69,7 @@ L<Test::Mojo::IRC>.
 
 =head2 close
 
-Emitted once the connection to the server close.
+Emitted once the connection to the server closes.
 
 =head2 error
 
@@ -77,30 +77,30 @@ Emitted once the stream emits an error.
 
 =head2 err_event_name
 
-Events that start with "err_" is emitted when there is an IRC response that
-indicate an error. See L<Mojo::IRC::Events> for example events.
+Events that start with "err_" are emitted when there is an IRC response that
+indicates an error. See L<Mojo::IRC::Events> for sample events.
 
 =head2 ctcp_event_name
 
-Events that start with "ctcp_" is emitted if the L</parser> can understand
-CTCP messages, and there is an CTCP response.
+Events that start with "ctcp_" are emitted if the L</parser> can understand
+CTCP messages, and there is a CTCP response.
 
   $self->parser(Parse::IRC->new(ctcp => 1);
 
-See L<Mojo::IRC::Events> for example events.
+See L<Mojo::IRC::Events> for sample events.
 
 =head2 irc_error
 
-This event is used to emit IRC errors. It is also possible for finer
-granularity to listen for events such as C<err_nicknameinuse>.
+This event is used to emit IRC errors. For finer granularity, it is also
+possible to listen for events such as C<err_nicknameinuse>.
 
 NOTE: L</irc_error> events are emitted even if you listen to C<err_> events,
 but they are always emitted I<after> the C<err_> event.
 
 =head2 irc_event_name
 
-Events that start with "irc_" is emit when there is a normal IRC response.
-See L<Mojo::IRC::Events> for example events.
+Events that start with "irc_" are emitted when there is a normal IRC response.
+See L<Mojo::IRC::Events> for sample events.
 
 =cut
 
@@ -116,7 +116,7 @@ use constant DEBUG => $ENV{MOJO_IRC_DEBUG} ? 1 : 0;
 use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE__), 'mojo-irc-client.crt';
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -131,6 +131,13 @@ my @DEFAULT_EVENTS = qw(
 
 Holds an instance of L<Mojo::IOLoop>.
 
+=head2 local_address
+
+  $str = $self->local_address;
+  $self = $self->local_address("10.20.30.40");
+
+Local address to bind to. See L<Mojo::IOLoop::Client/local_address>.
+
 =head2 name
 
 The name of this IRC client. Defaults to "Mojo IRC".
@@ -158,15 +165,15 @@ server that we are connected to.
 
 =head2 server
 
-Server name and optionally a port to connect to. Changing this while connected
-to the IRC server will issue a reconnect.
+Server name and, optionally, a port to connect to. Changing this while
+connected to the IRC server will issue a reconnect.
 
 =head2 tls
 
   $self->tls(undef) # disable (default)
   $self->tls({}) # enable
 
-Default is "undef" which disable TLS. Setting this to an empty hash will
+Default is "undef" which disables TLS. Setting this to an empty hash will
 enable TLS and this module will load in default certs. It is also possible
 to set custom cert/key:
 
@@ -184,13 +191,14 @@ IRC username. Defaults to current logged in user or falls back to "anonymous".
 =cut
 
 has ioloop => sub { Mojo::IOLoop->singleton };
-has name   => 'Mojo IRC';
-has nick   => sub { shift->_build_nick };
-has parser => sub { Parse::IRC->new; };
-has pass   => '';
-has real_host => '';
-has tls       => undef;
-has user      => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
+has local_address => '';
+has name          => 'Mojo IRC';
+has nick          => sub { shift->_build_nick };
+has parser        => sub { Parse::IRC->new; };
+has pass          => '';
+has real_host     => '';
+has tls           => undef;
+has user          => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
 
 sub server {
   my ($self, $server) = @_;
@@ -215,27 +223,34 @@ sub server {
 
   $self = $self->connect(\&callback);
 
-Will login to the IRC L</server> and call C<&callback> once connected. The
-C<&callback> will be called once connected or if it fail to connect. The
-second argument will be an error message or empty string on success.
+Will log in to the IRC L</server> and call C<&callback>. The
+C<&callback> will be called once connected or if connect fails. The second
+argument will be an error message or empty string on success.
 
 =cut
 
 sub connect {
   my ($self, $cb) = @_;
   my ($host, $port) = split /:/, $self->server;
-  my @tls;
+  my @extra;
 
+  if (!$host) {
+    Mojo::IOLoop->next_tick(sub { $self->$cb('server() is not set.') });
+    return $self;
+  }
   if ($self->{stream_id}) {
     Mojo::IOLoop->next_tick(sub { $self->$cb('') });
     return $self;
   }
 
+  if ($self->local_address) {
+    push @extra, local_address => $self->local_address;
+  }
   if (my $tls = $self->tls) {
-    push @tls, tls      => 1;
-    push @tls, tls_ca   => $tls->{ca} if $tls->{ca};       # not sure why this should be supported, but adding it anyway
-    push @tls, tls_cert => $tls->{cert} || DEFAULT_CERT;
-    push @tls, tls_key  => $tls->{key} || DEFAULT_KEY;
+    push @extra, tls      => 1;
+    push @extra, tls_ca   => $tls->{ca} if $tls->{ca};     # not sure why this should be supported, but adding it anyway
+    push @extra, tls_cert => $tls->{cert} || DEFAULT_CERT;
+    push @extra, tls_key  => $tls->{key} || DEFAULT_KEY;
   }
 
   $port ||= 6667;
@@ -247,7 +262,7 @@ sub connect {
   $self->{stream_id} = $self->ioloop->client(
     address => $host,
     port    => $port,
-    @tls,
+    @extra,
     sub {
       my ($loop, $err, $stream) = @_;
 
